@@ -1,6 +1,8 @@
 import boto3
 import watchtower
 import concurrent.futures
+from threading import Thread
+import queue
 from src.base_logger import BaseLogger
 
 
@@ -28,7 +30,23 @@ class CloudWatchLogger(BaseLogger):
 class AsyncCloudWatchHandler(watchtower.CloudWatchLogHandler):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.executor = concurrent.futures.ThreadPoolExecutor(max_workers=5)
+        self.log_queue = queue.Queue()
+        self.worker_thread = Thread(target=self._process_queue)
+        self.worker_thread.daemon = True
+        self.worker_thread.start()
 
     def emit(self, record):
-        self.executor.submit(super().emit, record)
\ No newline at end of file
+        self.log_queue.put(record)
+
+    def _process_queue(self):
+        while True:
+            record = self.log_queue.get()
+            if record is None:
+                break
+            super().emit(record)
+            self.log_queue.task_done()
+
+    def close(self):
+        self.log_queue.put(None)
+        self.worker_thread.join()
+        super().close()
\ No newline at end of file
